package com.lbe.doubleagent.service;

import com.lbe.doubleagent.client.IDAClient;
import com.lbe.doubleagent.service.DANotificationRecord;
import com.lbe.doubleagent.service.PendingResultInfo;
import com.lbe.doubleagent.service.PendingIntentData;
import com.lbe.doubleagent.service.DAParceledListSlice;
import android.app.job.JobWorkItem;

interface IDAActivityManager {
    // process
    int getProcessVPid(in int vuid, in String packageName, in String processName, in boolean createIfNeeded, in String reason);
    int forceStopPackage(in int vuid, in String packageName);
    int stopUser(in int vuid);

    // activity & task
    Intent startActivity(in int vuid, in int vpid, in IDAClient client, in IBinder caller, in String callerPackageName, in String callerActivityName, in Intent intent, in ActivityInfo activityInfo, in Bundle options, in int requestCode);
    Intent[] startActivities(in int vuid, in IDAClient client, in IBinder caller, in Intent[] intentArray, in ActivityInfo[] activityInfoArray, in Bundle options);
    oneway void onActivityCreate(in int vuid, in IDAClient client, in IBinder token, in ComponentName activity, in int activityFlags, in int launchMode, in String activityAffinity, in String taskAffinity, in int taskId, in Intent taskRoot, in int clearTarget, in int themeId, in int callerTaskId);
    oneway void onActivityResume(in int vuid, in IDAClient client, in ComponentName activity);
    oneway void onActivityAfterResume(in int vuid, in IDAClient client, in ComponentName activity, in int windowFlags, in int resumeCount);
    oneway void onActivityPause(in int vuid, in IDAClient client, in ComponentName activity);
    oneway void onActivityDestroy(IBinder token);
    void onActivityFinish(IBinder token);
    DAParceledListSlice getRunningTasks(in int vuid, in int maxNum);
    DAParceledListSlice getRecentTasks(in int vuid, in int maxNum, in int flags);
    DAParceledListSlice getRunningServices(in int vuid, in int maxNum);
    DAParceledListSlice getRunningAppProcesss(in int vuid);
    int getActivityThemeId(in int taskId, in IBinder token, in int step, in boolean matchPkg);
    boolean hasRunningActivity(in int vuid, in String packageName);

    // provider
    IBinder getContentProvider(in int vuid, in ProviderInfo providerInfo);

    // broadcast
    void registerBroadcastReceiver(in int vuid, in IDAClient client, in IBinder receiver, in IntentFilter filter);
    void unregisterBroadcastReceiver(in int vuid, in IDAClient client, in IBinder receiver);
    boolean canReceiveBroadcast(in int vuid, in Intent broadcast);
    void finishBroadcast(in int vuid, in IDAClient client, in PendingResultInfo pendingResultInfo);
    void broadcastToSystem(in Intent broadcast, in String permission, boolean ordered, boolean sticky);

    // job
    int scheduleJob(in int vuid, in String pkg, in int jobId, in String className, in PersistableBundle extras);
    int cancelJob(in int vuid, in String pkg, in int jobId);
    void cancelJobs(in int vuid, in String pkg);
    List<JobInfo> getAllPendingJobs(in int vuid, in String pkg);
    JobInfo getPendingJob(in int vuid, in String pkg, in int jobId);
    void proxyJobSchedule(in JobInfo jobInfo);
    void proxyCancelJob(in int jobId);
    void proxyCancelJobs();
    int proxyEnqueue(in JobInfo job, in JobWorkItem work);

    // report
    void reportAppCrash(in int vuid, in String pkg, in String stackTracein, in int waitTime);
    void reportGMSUncaughtException(in int vuid, in String pkg, in String stackTracein, in int waitTime);
    void reportFirstActivity(in int vuid, in int vpid, in String pkg, in String activity);

    // service
    boolean stopService(in int vuid, in String processName, in ComponentName componentName, in int startId);
    void addServiceConnection(in int vuid, in IDAClient client, in IBinder connection, in int vpid, in ComponentName service);
    void removeServiceConnection(in int vuid, in IDAClient client, in IBinder connection);
    void startHiddenForegroundService(in int vpid);
    PendingIntent getHiddenForegroundServiceIntent(in int vpid);
    void startGMSCheckInService(in int vuid);

    // notification
    int getNotificationIconOverride(in String pkg);
    DANotificationRecord getNotification(in int vpid, in int vuid, in String pkg, in int id, in String tag, in Notification notification, in ComponentName service, IBinder token);
    DANotificationRecord clearNotification(in int vuid, in String pkg, in int id, in String tag);
    void clearNotifications(in int vuid, in String pkg);
    void notifyServiceStopForeground(in int vuid, in ComponentName service, boolean removeNotificaiton);
    PendingIntent createNotificationProxyIntent(in int vuid, in String packageName, in int id, in String tag, in String position, in int type, in PendingIntent intent);
    DANotificationRecord getRealNotificationInfo(in int id, in String tag, in String packageName);

    // notification for Oreo
    Notification modifyNotification(in int vpid, in String packageName, in Notification oldNotification);
    boolean isNotificationChannelGroupExist(in int vpid, in String groupId);

    // settings
    String getSettingsProviderValue(in int vuid, in int type, in String key);
    void putSettingsProviderValue(in int vuid, in int type, in String key, in String value);
    void deleteSettingsProviderValue(in int vuid, in int type, in String key);

    // should move to package manager
    String[] getPidPackages(in int realPid);

    // permissions
    int checkPermission(in int vuid, in String permission, in int pid, in int uid);

    // pendingintents
    void setPendingIntentCache(in IBinder token, in String creator, in int type);
    String getPendingIntentCreator(in IBinder token);
    int getPendingIntentType(in IBinder token);
    void clearPendingIntentCache(in IBinder token);

    void notifyDownloadStarted(in int vuid, in long id, in String url, in String downloader);
    void notifyDownloadRemoved(in long[] ids);

    //shortcut border id
    int getShortCutBorderId();

    //for badge count
    void reportBadgerPackage(in int vuid, in String pkg, in String cls, in int count);

    //for PsBrowser
    ResolveInfo getPsBrowserActivityInfo(in int flag);

    void startHiddenForegroundServiceForNMR1(in ComponentName componentName, in int vpid);
    void stopHiddenForegroundServiceForNMR1(in int vpid);

    //report
    void reportActivityWindowBounds(in ComponentName activity, in Rect bounds);

    //for system Mode
    void setSystemMode(in int vpid, in int vuid, in int mode);
    int getSystemMode(in int vuid);

    //for foreground
    ComponentName getForegroundApp(in int vuid);
    DAParceledListSlice getRunningTaskForActivity(in int vuid, in IBinder token);
    oneway void onLastActivityFinish(IBinder token, String packagName);
    boolean isActivityInTaskExit(in int vuid, in IBinder token, in int taskId, in boolean isMoveTaskToBack, in String packageName);

    //for ad
    void onFirstActivityCreate(in int taskId);

    //for system exit
    void reportAppSystemExit(in int vuid, in int vpid, in String packageName);

    //for billing
    boolean getBillingStatus();

    // for JobScheduler
    void checkAllPendingJobs(in int vuid);

    String getTaskTopPackage(in int vuid, in IDAClient client, in IBinder caller);

    void linkerToDeath();
    void linkerToDeath2();

    boolean check64BitHelper();
    NotificationChannel getNotificationChannel(in int vuid, in int vpid, in String channelId);
    void createNotificationChannelProxy(in int vuid, in int vpid, in NotificationChannel channel);
}
