package com.lbe.doubleagent.service;

import com.lbe.doubleagent.service.DAPackage;
import com.lbe.doubleagent.service.ReceiverInfo;
import com.lbe.doubleagent.client.DACapabilities;
import com.lbe.doubleagent.service.parser.DAReceiverInfoCache;
import com.lbe.doubleagent.service.DAParceledListSlice;
import com.lbe.doubleagent.service.DADexOverride;
import com.lbe.doubleagent.service.packageinstaller.IDAPackageInstaller;
import com.lbe.doubleagent.service.packageinstaller.PackageInstallInfo;
import android.content.pm.PackageInfo;
import android.content.pm.ApplicationInfo;
import android.content.pm.ActivityInfo;
import android.content.pm.ServiceInfo;
import android.content.pm.ProviderInfo;
import android.content.pm.ResolveInfo;
import android.content.pm.IPackageDeleteObserver;
import android.content.pm.IPackageDeleteObserver2;
import android.content.pm.IPackageStatsObserver;
import android.content.pm.Signature;

interface IDAPackageManager {
    int installPackage(in int vuid, in String packageName);
    int uninstallPackage(in int vuid, in String packageName);
    int clearApplicationUserData(in int vuid, in String packageName);
    int deleteApplicationCacheFiles(in int vuid, in String packageName);
    int createUser();
    int removeUser(int vuid);
    int[] getUsers();
    String[] getInstalledPackageNames(in int vuid);
    int getInstalledPackages(in int vuid, in String caller, in int version, out DAParceledListSlice packageList);
    List<DAReceiverInfoCache> queryStaticReceivers(in int vuid, in String packageName);

//    int getComponentEnabledSetting(in int vuid, in ComponentName componentName);
    void setComponentEnabledSetting(in int vuid, in ComponentName componentName, in int newState, in int flags);

    boolean pluginHasSharedUid(in int vuid, String sharedUserName);

//    void clearPackagePreferredActivities(in int vuid, in String packageName);
//    String[] getPreferredPackageNames(in int vuid);
//    int getPreferredActivities(in int vuid, inout List outFilters, inout List outActivities, String packageName);

    void getPackageSizeInfo(in int vuid, in String packageName, in IPackageStatsObserver observer);

    IntentFilter checkForProtectedActions(in int vuid, in IntentFilter filter);

    DADexOverride[] getDexOverrides();

    int checkPermission(int vuid, String permissionName, String packageName, String hostPkg);
    void installPackageFromPm(in PackageInstallInfo packageInfo);
    boolean hasSameShareUid(in String firstPackage, in String secondPackage);
    void deletePackage(in int vuid, in String packageName, in IPackageDeleteObserver observer, in IPackageDeleteObserver2 observer2);
    ApplicationInfo getApplicationInfoFromSystem(in String packageName);

    PackageInfo getPluginPackageInfo(in int vuid, in String caller, in String packageName, in int flags);
    ApplicationInfo getPluginApplicationInfo(in int vuid, in String caller, in String packageName, in int flags);
    ActivityInfo getPluginActivityInfo(in int vuid, in String caller, in ComponentName componentName, in int flags);
    ActivityInfo getPluginReceiverInfo(in int vuid, in String caller, in ComponentName componentName, in int flags);
    ServiceInfo getPluginServiceInfo(in int vuid, in String caller, in ComponentName componentName, in int flags);
    ProviderInfo getPluginProviderInfo(in int vuid, in String caller, in ComponentName componentName, in int flags);
    List<ResolveInfo> queryPluginIntentActivities(in int vuid, in String caller, in Intent intent, in String resolvedType, in int flags);
    List<ResolveInfo> queryPluginIntentReceivers(in int vuid, in String caller, in Intent intent, in String resolvedType, in int flags);
    List<ResolveInfo> queryPluginIntentServices(in int vuid, in String caller, in Intent intent, in String resolvedType, in int flags);
    List<ResolveInfo> queryPluginIntentProviders(in int vuid, in String caller, in Intent intent, in String resolvedType, in int flags);
    List<PackageInfo> getPluginInstalledPackages(in int vuid, in String caller, in int flags);
    List<ApplicationInfo> getPluginInstalledApplications(in int vuid, in String caller, in int flags);
    ProviderInfo resolvePluginContentProvider(in int vuid, in String caller, in String name, in int flags);
    List<ProviderInfo> queryPluginContentProviders(in int vuid, in String caller, in String processName, in int flags);
    PermissionInfo getPluginPermissionInfo(in int vuid, in String caller, in String permission);
    PermissionGroupInfo getPluginPermissionGroupInfo(in int vuid, in String caller, in String group);
    List<PermissionInfo> queryPluginPermissionsByGroup(in int vuid, in String caller, String group);
    List<PermissionGroupInfo> getAllPluginPermissionGroups(in int vuid, in String caller);
    List<PackageInfo> getPluginPackagesHoldingPermissions(in int vuid, in String caller, in String[] permissions, int flags);

    void updateInstallTime(in int vuid, in String packageName, in long installTime);

    long get32BitMigrationDataSize(in int uid, in String packageName);
    long getSDFreeSize();
    int migrateDataStatus(in int vuid, in String packageName);
    void migrateDataFrom32BitTo64Bit(in int vuid, in String packageName, in ResultReceiver resultReceiver);
    void cancelMigrateData(in int vuid, in String packageName);
    DACapabilities getCapabilities(int vuid, String packageName, String processName);
}
