package com.lbe.mdremote.common;

import com.lbe.mdremote.common.DANotificationRecord;
import com.lbe.mdremote.common.DAJobInfo;
import com.lbe.mdremote.common.DAProcessInfo;
import com.lbe.mdremote.common.IDAPackageStatsObserver;
import com.lbe.mdremote.common.DAProcessRecord;
import android.app.job.JobInfo;
import android.os.Bundle;
import android.os.IBinder;
import android.app.PendingIntent;
import android.app.ActivityManager.RecentTaskInfo;
import android.app.job.JobWorkItem;

interface IDAActivityManager {
    // process
    int getProcessVPid(in int vuid, in String packageName, in String processName, in boolean createIfNeeded, in String reason);
    int forceStopPackage(in int vuid, in String packageName);
    int stopUser1(in int vuid);

    // activity & task
    //Intent startActivity(in int vuid, in DAClient client, in IBinder caller, in Intent intent, in ActivityInfo activityInfo, in Bundle options, in int requestCode);
   // Intent[] startActivities(in int vuid, in DAClient client, in IBinder caller, in Intent[] intentArray, in ActivityInfo[] activityInfoArray, in Bundle options);
    oneway void onActivityDestroy(in IBinder token);
    oneway void onActivityFinish(in IBinder token);
    int getActivityThemeId(in int taskId, in IBinder token, in int step, in boolean matchPkg);

    // provider
    IBinder getContentProvider(in int vuid, in ProviderInfo providerInfo);

    // broadcast
    //void registerBroadcastReceiver(in int vuid, in DAClient client, in IBinder receiver, in IntentFilter filter);
    //void unregisterBroadcastReceiver(in int vuid, in DAClient client, in IBinder receiver);
    boolean canReceiveBroadcast(in int vuid, in Intent broadcast);
    void broadcastToSystem(in Intent broadcast, in String permission, in boolean ordered, in boolean sticky);

    // job
    int scheduleJob(in int vuid, in String pkg, in int jobId, in String className, in PersistableBundle extras);
    int cancelJob(in int vuid, in String pkg, in int jobId);
    void cancelJobs(in int vuid, in String pkg);
    List<JobInfo> getAllPendingJobs(in int vuid, in String pkg);
    int proxyEnqueue(in JobInfo job, in JobWorkItem work);

    // report
    void reportAppCrash(in int vuid, in String pkg, in String stackTracein, in int waitTime);
    void reportFirstActivity(in int vuid, in int vpid, in String pkg, in String activity);

    // service
    boolean stopService(in int vuid, in String processName, in ComponentName componentName, in int startId);
    void startHiddenForegroundService(in int vpid);
    PendingIntent getHiddenForegroundServiceIntent(in int vpid);

    // notification
    int getNotificationIconOverride(in String pkg);
    // DANotificationRecord getNotification(in int vuid, in String pkg, in int id, in String tag, in Notification notification, in ComponentName service, IBinder token);
    // DANotificationRecord clearNotification(in int vuid, in String pkg, in int id, in String tag);
    void clearNotifications(in int vuid, in String pkg);
    //void notifyServiceStopForeground(in int vuid, in ComponentName service, boolean removeNotificaiton);
    PendingIntent createNotificationProxyIntent(in int vuid, in String packageName, in int id, in String tag, in String position, in PendingIntent intent);
    // notification for Oreo
    Notification modifyNotification(in int vpid, in String packageName, in Notification oldNotification);

    // settings
    String getSettingsProviderValue(in int vuid, in int type, in String key);
    void putSettingsProviderValue(in int vuid, in int type, in String key, in String value);
    void deleteSettingsProviderValue(in int vuid, in int type, in String key);

    // should move to package manager
    String[] getPidPackages(in int realPid);

    // permissions
    int checkPermission(in int vuid, in String permission, in int pid, in int uid);

    // pendingintents
    void setPendingIntentCache(in IBinder token, in String creator, in int type);
    String getPendingIntentCreator(in IBinder token);
    int getPendingIntentType(in IBinder token);
    void clearPendingIntentCache(in IBinder token);

    void notifyDownloadStarted(in int vuid, in long id, in String url, in String downloader);
    void notifyDownloadRemoved(in long[] ids);

    //shortcut border id
    int getShortCutBorderId();

    //for badge count
    void reportBadgerPackage(in int vuid, in String pkg, in String cls, in int count);

    //ext
    void handlePackageUpdate(in int vuid, in String packageName);
    //boolean initialized();
    boolean isGMSStarted(in int vuid);
    boolean isLowMemoryMode();
    boolean isPackageRunning(in int vuid, in String packageName);
    boolean isProcessHasStartedActivity(in int vuid, in String packageName,in String processName);
    //void launchPackageAsUser(in int vuid, in String packageName);
    void launchPackageAsUserWithOptions(in int vuid, in String packageName, in Bundle options);
    void onMobileAppDownloadAutoCancel(in String packageName);
    void onNewAccountAdded( in String type);

    void registerStatsObserver(in IDAPackageStatsObserver observer);
    void reportAppProcessStart(in int vuid, in int vpid, in int pid, in String pkg, in boolean refresh);
    void reportPackageStart(in String pkg);
    void reset();
    boolean sendBroadcastAsUser(in int vuid, in Intent intent);
    void setLowMemoryMode(in boolean lowMemoryMode);
    void startActivityAsUserWithOptions(in int vuid, in Intent activity, in Bundle options);
    //void startServiceAsUser(in int vuid, in Intent service);
    void startServiceAsUser2(in int vuid, in ServiceInfo serviceInfo, in Intent service);
    //int  stopUser(in int vuid, in boolean killGoogleApps);
    //int  stopUser(in int vuid, in Set skipPackages);
    void unregisterStatsObserver(in IDAPackageStatsObserver observer);
    void wakeupApps(in boolean boot);
    //todo: new added interface check later
    // boolean bindServiceAsUser(in int vuid, in Intent service,out ServiceConnection connection,in int flags);//check serviceconn
    // boolean bindServiceAsUser(in int vuid, in ServiceInfo serviceInfo, in Intent service, out ServiceConnection connection, in int flags);
    void checkPackageNotResponding(in int vuid, in String packageName);
    boolean currentOnTop(in int pid);
    void disableAppProxy(in int vuid);
    void enableAppProxy(in int vuid);
    boolean filterBroadcast(in int vuid, in Intent broadcast, in String receiverPkg);
    //todo:
    DAJobInfo getJobId(in int realId);
    //todo
    //Set<String> getRunningPackages(int vuid);
    //todo
    //List<DAProcessInfo> getRunningProcessInfo(in int vuid, in int flag);
    void startActivityAsUser(int vuid, in Intent activity);
    void launchPackageAsUser(int vuid, String packageName);
    List<String> getRunningPackagesSnapshot();
    //boolean bindServiceAsUser(int vuid, in Intent service, in ServiceConnection connection, int flags)
    List getRecentTasks(int vuid, int maxNum, int flags);
    DANotificationRecord clearNotification(int vuid, String pkg, int id, String tag);
    List getRunningAppProcesss(int vuid);
    List getRunningProcessInfo(int vuid, int flag);
    int stopUser2(int vuid, boolean killGoogleApps);
    int stopUser(int vuid,in List<String> skipPackages);
    List<String> getRunningPackages(int vuid);
    DAProcessRecord findProcessRecordByPid(int pid);
    List getRunningServices(int vuid, int maxNum);
    void notifyServiceStopForeground(int vuid, in ComponentName serviceComponent, boolean modifyNotification);
    DANotificationRecord getNotification(in int vpid, in int vuid, in String pkg,in int id,in String tag,in Notification notification, in ComponentName service, in IBinder token);
    List getRunningTasks(int vuid, int maxNum);
    void startServiceAsUser(int vuid, in Intent service);
    boolean initialized();
    void onActivityResume(in ComponentName componentName);
    void setSystemMode(in int vpid, in int vuid, in int mode);
    void setGMSEnabled(in boolean enabled);
    boolean isGMSEnabled();
    ComponentName getForegroundApp(in int vuid);

    boolean hasRunningActivity(in int vuid, in String packageName);
}
